package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaPerson;
import com.shigongli.service.ITaPersonService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaShopKeeperService;
import com.shigongli.entity.TaShopKeeper;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 店主 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "店主")
@RestController
@RequestMapping("/")
public class TaShopKeeperController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopKeeperController.class);

    @Autowired
    public ITaShopKeeperService iTaShopKeeperService;

    @Autowired
    public ITaPersonService iTaPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/mp/taShopKeeper",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopKeeperList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @ApiParam("店铺ID") @RequestParam("shopId") String shopId) throws Exception{

		    IPage<TaShopKeeper> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaShopKeeper> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("shop_id", shopId);
            queryWrapper.eq("status", StatusConstant.NORMAL);
            queryWrapper.orderByDesc("create_date");

            IPage<TaShopKeeper> result = iTaShopKeeperService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taShopKeeper 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taShopKeeper",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taShopKeeperAdd(@ApiParam("保存内容") @RequestBody TaShopKeeper taShopKeeper) throws Exception{

        TaPerson taPerson = iTaPersonService.getByPhone(taShopKeeper.getPhone());
        if (null != taPerson) {
            taShopKeeper.setPersonId(taPerson.getPersonId());
        }

        if (iTaShopKeeperService.save(taShopKeeper)){
            return ResponseBean.success(taShopKeeper);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taShopKeeper/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taShopKeeperDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaShopKeeper taShopKeeper = iTaShopKeeperService.getById(id);
        if (null == taShopKeeper || taShopKeeper.getStatus().equals(StatusConstant.DELETE)) {
            return ResponseBean.success("ok");
        }

        taShopKeeper.setStatus(StatusConstant.DELETE);
        return taShopKeeperUpdate(id, taShopKeeper);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taShopKeeper 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taShopKeeper/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taShopKeeperUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaShopKeeper taShopKeeper) throws Exception{

        TaPerson taPerson = iTaPersonService.getByPhone(taShopKeeper.getPhone());
        if (null != taPerson) {
            taShopKeeper.setPersonId(taPerson.getPersonId());
        }

        if (iTaShopKeeperService.updateById(taShopKeeper)){
            return ResponseBean.success(iTaShopKeeperService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taShopKeeper/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopKeeperGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaShopKeeperService.getById(id));
    }
}
